.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents
--------

.. toctree::
   :maxdepth: 1

   hope
   lang
   arch
   contributing
   authors
   history

Benchmarks
----------

All the benchmarks have been made available online as `IPython notebooks
<http://cosmo-docs.phys.ethz.ch/hope/benchmarks>`_.

Test coverage
-------------

`Test coverage reports <http://cosmo-docs.phys.ethz.ch/hope/htmlcov>`_.
